==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/storsimple/kotlin/inputs/AsymmetricEncryptedSecretArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storsimple.kotlin.inputs

import com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs.builder
import com.pulumi.azurenative.storsimple.kotlin.enums.EncryptionAlgorithm
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represent the secrets intended for encryption with asymmetric key pair.
 * @property encryptionAlgorithm The algorithm used to encrypt "Value".
 * @property encryptionCertThumbprint Thumbprint certificate that was used to encrypt "Value". If the value in unencrypted, it will be null.
 * @property value The value of the secret.
 */
public data class AsymmetricEncryptedSecretArgs(
    public val encryptionAlgorithm: Output<EncryptionAlgorithm>,
    public val encryptionCertThumbprint: Output<String>? = null,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs> {
    override fun toJava(): com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs =
        com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs.builder()
            .encryptionAlgorithm(
                encryptionAlgorithm.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .encryptionCertThumbprint(encryptionCertThumbprint?.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AsymmetricEncryptedSecretArgs].
 */
@PulumiTagMarker
public class AsymmetricEncryptedSecretArgsBuilder internal constructor() {
    private var encryptionAlgorithm: Output<EncryptionAlgorithm>? = null

    private var encryptionCertThumbprint: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The algorithm used to encrypt "Value".
     */
    @JvmName("wrwatchusutsahcw")
    public suspend fun encryptionAlgorithm(`value`: Output<EncryptionAlgorithm>) {
        this.encryptionAlgorithm = value
    }

    /**
     * @param value Thumbprint certificate that was used to encrypt "Value". If the value in unencrypted, it will be null.
     */
    @JvmName("emkirjpsxladlrtt")
    public suspend fun encryptionCertThumbprint(`value`: Output<String>) {
        this.encryptionCertThumbprint = value
    }

    /**
     * @param value The value of the secret.
     */
    @JvmName("mhqfijqmtcmluscr")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The algorithm used to encrypt "Value".
     */
    @JvmName("xqhgfglmcogromem")
    public suspend fun encryptionAlgorithm(`value`: EncryptionAlgorithm) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionAlgorithm = mapped
    }

    /**
     * @param value Thumbprint certificate that was used to encrypt "Value". If the value in unencrypted, it will be null.
     */
    @JvmName("meunqfahanqxxdyk")
    public suspend fun encryptionCertThumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionCertThumbprint = mapped
    }

    /**
     * @param value The value of the secret.
     */
    @JvmName("xdjvrhyylsyfvduc")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): AsymmetricEncryptedSecretArgs = AsymmetricEncryptedSecretArgs(
        encryptionAlgorithm = encryptionAlgorithm ?: throw PulumiNullFieldException("encryptionAlgorithm"),
        encryptionCertThumbprint = encryptionCertThumbprint,
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/storsimple/kotlin/inputs/AsymmetricEncryptedSecretArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.storsimple.kotlin.inputs

import com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs.builder
import com.pulumi.azurenative.storsimple.kotlin.enums.EncryptionAlgorithm
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Represent the secrets intended for encryption with asymmetric key pair.
 * @property encryptionAlgorithm The algorithm used to encrypt "Value".
 * @property encryptionCertThumbprint Thumbprint certificate that was used to encrypt "Value". If the value in unencrypted, it will be null.
 * @property value The value of the secret.
 */
public data class AsymmetricEncryptedSecretArgs(
    public val encryptionAlgorithm: Output<EncryptionAlgorithm>,
    public val encryptionCertThumbprint: Output<String>? = null,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs> {
    override fun toJava(): com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs =
        com.pulumi.azurenative.storsimple.inputs.AsymmetricEncryptedSecretArgs.builder()
            .encryptionAlgorithm(
                encryptionAlgorithm.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .encryptionCertThumbprint(encryptionCertThumbprint?.applyValue({ args0 -> args0 }))
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AsymmetricEncryptedSecretArgs].
 */
@PulumiTagMarker
public class AsymmetricEncryptedSecretArgsBuilder internal constructor() {
    private var encryptionAlgorithm: Output<EncryptionAlgorithm>? = null

    private var encryptionCertThumbprint: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value The algorithm used to encrypt "Value".
     */
    @JvmName("wyxhvthwuhjhxvbj")
    public suspend fun encryptionAlgorithm(`value`: Output<EncryptionAlgorithm>) {
        this.encryptionAlgorithm = value
    }

    /**
     * @param value Thumbprint certificate that was used to encrypt "Value". If the value in unencrypted, it will be null.
     */
    @JvmName("uwcjyxllqxadmiha")
    public suspend fun encryptionCertThumbprint(`value`: Output<String>) {
        this.encryptionCertThumbprint = value
    }

    /**
     * @param value The value of the secret.
     */
    @JvmName("tcueooyimhcjjhyi")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value The algorithm used to encrypt "Value".
     */
    @JvmName("vneblhxfwtbpbfqh")
    public suspend fun encryptionAlgorithm(`value`: EncryptionAlgorithm) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.encryptionAlgorithm = mapped
    }

    /**
     * @param value Thumbprint certificate that was used to encrypt "Value". If the value in unencrypted, it will be null.
     */
    @JvmName("nwuyotsdcxpfsack")
    public suspend fun encryptionCertThumbprint(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptionCertThumbprint = mapped
    }

    /**
     * @param value The value of the secret.
     */
    @JvmName("qhfshmwgvlboehxr")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): AsymmetricEncryptedSecretArgs = AsymmetricEncryptedSecretArgs(
        encryptionAlgorithm = encryptionAlgorithm ?: throw PulumiNullFieldException("encryptionAlgorithm"),
        encryptionCertThumbprint = encryptionCertThumbprint,
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
